# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ReportsV3UpdateParams"]


class ReportsV3UpdateParams(TypedDict, total=False):
    outline_id: int

    profile_id: int
