# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from ..shared.report import Report

__all__ = ["ReportListResponse"]

ReportListResponse: TypeAlias = List[Report]
