# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .prompt_template import PromptTemplate

__all__ = ["PromptTemplateListResponse"]

PromptTemplateListResponse: TypeAlias = List[PromptTemplate]
