# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .outline import Outline

__all__ = ["OutlineListResponse"]

OutlineListResponse: TypeAlias = List[Outline]
