# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .field import Field

__all__ = ["FieldListResponse"]

FieldListResponse: TypeAlias = List[Field]
