# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["Outline"]


class Outline(BaseModel):
    id: int

    perspective: str

    outline: Optional[object] = None
